==> libgwenhywfar_2.2.0.orig.tar.gz: gwenhywfar-2.2.0/src/version.h <==
/***************************************************************************
 $RCSfile$
 -------------------
 cvs         : $Id: version.h.in 832 2005-08-17 14:09:29Z aquamaniac $
 begin       : Wed Sep 24 2003
 copyright   : (C) 2003 by Martin Preuss
 email       : martin@libchipcard.de

 ***************************************************************************
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Lesser General Public            *
 *   License as published by the Free Software Foundation; either          *
 *   version 2.1 of the License, or (at your option) any later version.    *
 *                                                                         *
 *   This library is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *   Lesser General Public License for more details.                       *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the Free Software   *
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston,                 *
 *   MA  02111-1307  USA                                                   *
 *                                                                         *
 ***************************************************************************/


#ifndef GWENHYWFAR_VERSION_H
#define GWENHYWFAR_VERSION_H

#define GWEN_VERSION_MAJOR 2
#define GWENHYWFAR_VERSION_MAJOR 2
#define GWENHYWFAR_VERSION_MINOR 2
#define GWENHYWFAR_VERSION_PATCHLEVEL 0
#define GWENHYWFAR_VERSION_BUILD 0
#define GWENHYWFAR_VERSION_TAG "stable"
#define GWENHYWFAR_VERSION_FULL_STRING "2.2.0-stable-r0"
#define GWENHYWFAR_VERSION_STRING "2.2.0"

#define GWENHYWFAR_SO_EFFECTIVE 38
#define GWENHYWFAR_SO_EFFECTIVE_STR "38"


#endif /* GWENHYWFAR_VERSION_H */

==> libgwenhywfar_4.0.3.orig.tar.gz: gwenhywfar-4.0.3/src/version.h <==
/***************************************************************************
 $RCSfile$
 -------------------
 cvs         : $Id$
 begin       : Wed Sep 24 2003
 copyright   : (C) 2003 by Martin Preuss
 email       : martin@libchipcard.de

 ***************************************************************************
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Lesser General Public            *
 *   License as published by the Free Software Foundation; either          *
 *   version 2.1 of the License, or (at your option) any later version.    *
 *                                                                         *
 *   This library is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *   Lesser General Public License for more details.                       *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the Free Software   *
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston,                 *
 *   MA  02111-1307  USA                                                   *
 *                                                                         *
 ***************************************************************************/


#ifndef GWENHYWFAR_VERSION_H
#define GWENHYWFAR_VERSION_H

#define GWEN_VERSION_MAJOR 4
#define GWENHYWFAR_VERSION_MAJOR 4
#define GWENHYWFAR_VERSION_MINOR 0
#define GWENHYWFAR_VERSION_PATCHLEVEL 3
#define GWENHYWFAR_VERSION_BUILD 0
#define GWENHYWFAR_VERSION_TAG "stable"
#define GWENHYWFAR_VERSION_FULL_STRING "4.0.3stable-0"
#define GWENHYWFAR_VERSION_STRING "4.0.3"

#define GWENHYWFAR_SO_EFFECTIVE 60
#define GWENHYWFAR_SO_EFFECTIVE_STR "60"


#endif /* GWENHYWFAR_VERSION_H */
